==> stylish-haskell-0.14.3.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stylish-haskell
version:              0.14.3.0
visibility:           public
id:                   stylish-haskell-0.14.3.0-Fu7hL5P7LCpIUywavcFm94
key:                  stylish-haskell-0.14.3.0-Fu7hL5P7LCpIUywavcFm94
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  2eee2ca7bf18b260f383d39dfded586b
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stylish-haskell-0.14.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stylish-haskell-0.14.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.3.0-Fu7hL5P7LCpIUywavcFm94
depends:
    Cabal-3.6.3.0 HsYAML-0.2.1.3-7JxAPJpJJ8CKBPYAagF4LI
    HsYAML-aeson-0.2.0.1-73JMy2iKL602CbOsj8S5xx
    aeson-2.1.2.1-8ueLuG1qYj9Fbt4mgkSEM3 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    ghc-9.2.8 ghc-boot-9.2.8 ghc-boot-th-9.2.8
    ghc-lib-parser-ex-9.2.1.1-4bcAKxMnQiW3jfwryL8JXf mtl-2.2.2
    regex-tdfa-1.3.2.2-J4ofX6nqvlhJHKSDmvaDcK
    syb-0.7.2.4-3hS53rZXvyRCGaWO0KMGhq text-1.2.5.0

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.14.3.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stylish-haskell
version:              0.14.3.0
visibility:           public
id:                   stylish-haskell-0.14.3.0-L0yp5KGVDqb4GHWt5fooov
key:                  stylish-haskell-0.14.3.0-L0yp5KGVDqb4GHWt5fooov
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  a3ee6031f71d9b047ee8e90b481d9260
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stylish-haskell-0.14.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stylish-haskell-0.14.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.3.0-L0yp5KGVDqb4GHWt5fooov
depends:
    Cabal-3.6.3.0 HsYAML-0.2.1.3-7Zx7gg5rSIdHlsur8jGrP
    HsYAML-aeson-0.2.0.1-K3GqYaUDEzbBOXxsBlwky9
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    ghc-9.2.8 ghc-boot-9.2.8 ghc-boot-th-9.2.8
    ghc-lib-parser-ex-9.2.1.1-J7FUPaM3Lf6Fd6KLhB3yzS mtl-2.2.2
    regex-tdfa-1.3.2.2-D3LpMz1GC7yHTJs5TZ8Rua
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
